==> zeusmp1.5.10.tar.gz: zeusmp/src/scratch.h <==
      REAL  w1da(ijkn    ) , w1db(ijkn    ) , w1dc(ijkn    )
     &,     w1dd(ijkn    ) , w1de(ijkn    ) , w1df(ijkn    )
     &,     w1dg(ijkn    ) , w1dh(ijkn    ) , w1di(ijkn    )
     &,     w1dj(ijkn    ) , w1dk(ijkn    ) , w1dl(ijkn    )
     &,     w1dm(ijkn    ) , w1dn(ijkn    ) , w1do(ijkn    )
     &,     w1dp(ijkn    ) , w1dq(ijkn    ) , w1dr(ijkn    )
     &,     w1ds(ijkn    ) , w1dt(ijkn    ) , w1du(ijkn    )

c added 1D arrays w1dk through w1du for MHD  M-MML 4 Mar 98

      REAL  w3da(in,jn,kn) , w3db(in,jn,kn) , w3dc(in,jn,kn)
     &,     w3dd(in,jn,kn) , w3de(in,jn,kn) , w3df(in,jn,kn)
     &,     w3dg(in,jn,kn)
     &,     w3di(in,jn,kn) , w3dj(in,jn,kn)
#if defined RAD_EXP || defined RAD
     &,     w3dh(in,jn,kn)
#endif /* RAD_EXP || RAD */

      common /scratch/  w1da,w1db,w1dc,w1dd,w1de,w1df
     &,                 w1dg,w1dh,w1di,w1dj,w1dk,w1dl,w1dm
     &,                 w1dn,w1do,w1dp,w1dq,w1dr,w1ds,w1dt
     &,                 w1du
      common /scratch/  w3da,w3db,w3dc,w3dd,w3de,w3df,w3dg
     &,                 w3di,w3dj
#if defined RAD_EXP || defined RAD
     &,                 w3dh
#endif /* RAD_EXP || RAD */
#if defined RAD_LOSS || defined T_CONDUCT
      REAL cism,rcore,ncent,tmin
      common /scratch/ cism,rcore,ncent,tmin
#endif /* RAD_LOSS || T_CONDUCT */

c These are variables for rgjet.F PROBLEM routine
      REAL djet,v1jet,jetsize,efficiency
      REAL rin,jettheta
      common /scratch/ djet,v1jet,jetsize,efficiency
      common /scratch/ rin, jettheta

c These are variables for delayed.F BNDYUPDATE routine
       REAL mdota(20001)
       integer counter
       integer counter2
       REAL tcounter,mjet
       common /scratch/ mdota, counter,counter2,tcounter,mjet

==> zeusmp1.5.13.tar.gz: zeusmp/src/scratch.h <==
      REAL  w1da(ijkn    ) , w1db(ijkn    ) , w1dc(ijkn    )
     &,     w1dd(ijkn    ) , w1de(ijkn    ) , w1df(ijkn    )
     &,     w1dg(ijkn    ) , w1dh(ijkn    ) , w1di(ijkn    )
     &,     w1dj(ijkn    ) , w1dk(ijkn    ) , w1dl(ijkn    )
     &,     w1dm(ijkn    ) , w1dn(ijkn    ) , w1do(ijkn    )
     &,     w1dp(ijkn    ) , w1dq(ijkn    ) , w1dr(ijkn    )
     &,     w1ds(ijkn    ) , w1dt(ijkn    ) , w1du(ijkn    )

c added 1D arrays w1dk through w1du for MHD  M-MML 4 Mar 98

      REAL  w3da(in,jn,kn) , w3db(in,jn,kn) , w3dc(in,jn,kn)
     &,     w3dd(in,jn,kn) , w3de(in,jn,kn) , w3df(in,jn,kn)
     &,     w3dg(in,jn,kn)
     &,     w3di(in,jn,kn) , w3dj(in,jn,kn)
#if defined RAD_EXP || defined RAD
     &,     w3dh(in,jn,kn)
#endif /* RAD_EXP || RAD */

      common /scratch/  w1da,w1db,w1dc,w1dd,w1de,w1df
     &,                 w1dg,w1dh,w1di,w1dj,w1dk,w1dl,w1dm
     &,                 w1dn,w1do,w1dp,w1dq,w1dr,w1ds,w1dt
     &,                 w1du
      common /scratch/  w3da,w3db,w3dc,w3dd,w3de,w3df,w3dg
     &,                 w3di,w3dj
#if defined RAD_EXP || defined RAD
     &,                 w3dh
#endif /* RAD_EXP || RAD */
#if defined RAD_LOSS || defined T_CONDUCT
      REAL cism,rcore,ncent,tmin
      common /scratch/ cism,rcore,ncent,tmin
#endif /* RAD_LOSS || T_CONDUCT */

c These are variables for rgjet.F PROBLEM routine
      REAL djet,v1jet,jetsize,efficiency,mcutoff
      REAL rin,jettheta
      common /scratch/ djet,v1jet,jetsize,efficiency,mcutoff
      common /scratch/ rin, jettheta

c These are variables for delayed.F BNDYUPDATE routine
       REAL mdota(20001)
       integer counter
       integer counter2
       REAL tcounter,mjet
       common /scratch/ mdota, counter,counter2,tcounter,mjet

c These are variables for precess.F PROBLEM/BNDYUPDATE routine
       REAL palpha, pomega
       common /prec/ palpha, pomega
